﻿using System;
using System.Data;
using System.Windows.Forms;
using C1.Win.C1FlexGrid;

namespace FlexGrid.FixedCheckBox
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            //enabling OwnerDraw
            c1FlexGrid1.DrawMode = DrawModeEnum.OwnerDraw;
            c1FlexGrid1.OwnerDrawCell += C1FlexGrid1_OwnerDrawCell;

            //Set datatype and image-alignment for the fixed column
            c1FlexGrid1.Cols[0].DataType = typeof(bool);
            c1FlexGrid1.Cols[0].ImageAlign = ImageAlignEnum.CenterCenter;

            //Setting sample data
            c1FlexGrid1.DataSource = GetDataTable();

            //Handle AfterEdit event to update the fixed column
            c1FlexGrid1.AfterEdit += C1FlexGrid1_AfterEdit;
        }

        private void C1FlexGrid1_AfterEdit(object sender, RowColEventArgs e)
        {
            //If color column is edited, invalidate the fixed column to update the checkbox
            if (c1FlexGrid1.Cols[e.Col].Name.Equals("Color"))
                c1FlexGrid1.Invalidate(e.Row, 0);
        }

        private void C1FlexGrid1_OwnerDrawCell(object sender, OwnerDrawCellEventArgs e)
        {
            //Return if event is only fired for measuring the cell
            if (e.Measuring) return;

            //if data row and fixed column
            if (e.Row >= c1FlexGrid1.Rows.Fixed && e.Col == 0)
            {
                //check the data in the required column
                if (Enum.TryParse(c1FlexGrid1[e.Row, "Color"].ToString(), out CustomColor result) && result == CustomColor.Red)
                {
                    //draw only background, border and not the default checkbox image
                    e.DrawCell(DrawCellFlags.Border | DrawCellFlags.Background);

                    //indicate that the drawing for this cell is handled
                    e.Handled = true;
                }
            }
        }

        /// <summary>
        /// Sample DataTable for the grid
        /// </summary>
        private DataTable GetDataTable()
        {
            DataTable dt = new DataTable();
            dt.Columns.Add("ID", typeof(int));
            dt.Columns.Add("Color", typeof(CustomColor));
            for (int i = 1; i <= 20; i++)
            {
                dt.Rows.Add(i, i % 2 == 0 ? CustomColor.Red : CustomColor.Blue);
            }
            return dt;
        }
    }

    internal enum CustomColor
    {
        Red,
        Blue
    }
}
